@@ -1,4 +1,6 @@
 from .campbell import campbell
+from .mcmichael import mcmichael
+from .plain import plain
 from .edr import EDR
 from .fetch import fetch
 from .output import gen_segy, gen_tiff
